@@ -1,4 +1,5 @@
 from pathlib import Path
+from typing import Tuple
 
 from open_dread_rando import lua_util
 from open_dread_rando.patcher_editor import PatcherEditor, path_for_level
@@ -6,18 +7,34 @@ from open_dread_rando.patcher_editor import PatcherEditor, path_for_level
 
 def _read_powerup_lua() -> bytes:
     return Path(__file__).parent.joinpath("files", "randomizer_powerup.lua").read_bytes()
-
+def _read_level_lua(level_id: str) -> str:
+    return Path(__file__).parent.joinpath("files", "levels", f"{level_id}.lc.lua").read_text()
 
 class LuaEditor:
     def __init__(self):
         self._progressive_classes = {}
         self._powerup_script = _read_powerup_lua()
-        self._custom_level_scripts: dict[str, str] = {}
+        self._custom_level_scripts: dict[str, dict] = self._read_levels()
+        self._corex_replacement = {}
+
+    def _read_levels(self) -> dict[str, dict]:
+        scenarios = {
+            "s010_cave", "s020_magma", "s030_baselab", "s040_aqua", "s050_forest",
+            "s060_quarantine", "s070_basesanc", "s080_shipyard", "s090_skybase"
+        }
+        return {scenario: {"script": _read_level_lua(scenario), "edited": False} for scenario in scenarios}
+
+    def get_parent_for(self, item_id) -> str:
+        if item_id == "ITEM_WEAPON_POWER_BOMB":
+            return "RandomizerPowerBomb"
+        if item_id == "ITEM_OPTIC_CAMOUFLAGE":
+            return "RandomizerPhantomCloak"
+        return "RandomizerPowerup"
 
     def get_script_class(self, pickup_resources: list[dict], boss: bool = False) -> str:
-        main_pb = pickup_resources[0]["item_id"] == "ITEM_WEAPON_POWER_BOMB"
+        parent = self.get_parent_for(pickup_resources[0]["item_id"])
         if not boss and len(pickup_resources) == 1:
-            return "RandomizerPowerBomb" if main_pb else "RandomizerPowerup"
+            return parent
 
         hashable_progression = "_".join([f'{res["item_id"]}_{res["quantity"]}' for res in pickup_resources])
 
@@ -36,7 +53,7 @@ class LuaEditor:
         replacement = {
             "name": class_name,
             "progression": resources,
-            "parent": "RandomizerPowerBomb" if main_pb else "RandomizerPowerup",
+            "parent": parent,
         }
         self.add_progressive_class(replacement)
 
@@ -52,13 +69,9 @@ class LuaEditor:
         scenario_path = path_for_level(scenario)
         lua_util.create_script_copy(editor, scenario_path)
 
-        if scenario not in self._custom_level_scripts.keys():
-            self._custom_level_scripts[scenario] = "\n".join([
-                f"Game.LogWarn(0, 'Loading original {scenario}...')",
-                f"Game.ImportLibrary('{scenario_path}_original.lua')",
-                f"Game.LogWarn(0, 'Loaded original {scenario}.')",
-                f"Game.DoFile('actors/items/randomizer_powerup/scripts/randomizer_powerup.lua')\n\n",
-            ])
+        if not self._custom_level_scripts[scenario]["edited"]:
+            self._custom_level_scripts[scenario]["script"] += "\nGame.DoFile('actors/items/randomizer_powerup/scripts/randomizer_powerup.lua')\n\n"
+            self._custom_level_scripts[scenario]["edited"] = True
 
         replacement = {
             "scenario": scenario,
@@ -66,9 +79,17 @@ class LuaEditor:
             "pickup_class": self.get_script_class(resources, True),
             "args": ", ".join([f"_ARG_{i}_" for i in range(pickup_lua_callback["args"])])
         }
-        self._custom_level_scripts[scenario] += lua_util.replace_lua_template("boss_powerup_template.lua", replacement)
+        self._custom_level_scripts[scenario]["script"] += lua_util.replace_lua_template("boss_powerup_template.lua", replacement)
+    
+    def patch_corex_pickup_script(self, editor: PatcherEditor, resources: list[dict], pickup_lua_callback: dict):
+        bossid = pickup_lua_callback["function"]
+        self._corex_replacement[bossid] = self.get_script_class(resources, True)
 
     def save_modifications(self, editor: PatcherEditor):
         editor.replace_asset("actors/items/randomizer_powerup/scripts/randomizer_powerup.lc", self._powerup_script)
         for scenario, script in self._custom_level_scripts.items():
-            editor.replace_asset(path_for_level(scenario) + ".lc", script.encode("utf-8"))
+            editor.replace_asset(path_for_level(scenario) + ".lc", script["script"].encode("utf-8"))
+        
+        corex_script = lua_util.replace_lua_template("custom_corex.lua", self._corex_replacement).encode("utf-8")
+        for boss in {"core_x", "core_x_superquetzoa"}:
+            editor.replace_asset(f"actors/characters/{boss}/scripts/{boss}.lc", corex_script)
